"""Schema module - Pydantic models for configuration."""

from praisonaiui.schema.models import (
    A11yConfig,
    ComponentConfig,
    Config,
    ContentConfig,
    ContentSourceConfig,
    I18nConfig,
    NavConfig,
    RouteConfig,
    SEOConfig,
    SiteConfig,
    SlotRef,
    TemplateConfig,
    ThemeConfig,
)

__all__ = [
    "A11yConfig",
    "ComponentConfig",
    "Config",
    "ContentConfig",
    "ContentSourceConfig",
    "I18nConfig",
    "NavConfig",
    "RouteConfig",
    "SEOConfig",
    "SiteConfig",
    "SlotRef",
    "TemplateConfig",
    "ThemeConfig",
]
